==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/sv-SE/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Den här användaren kan logga in',
    'activated_disabled_help_text' => 'Du kan inte redigera aktiveringsstatus för ditt eget konto.',
    'assets_user'       => 'Tillgångar tilldelade: namn',
    'bulk_update_warn'	=> 'Du håller på att redigera egenskaperna hos: user_count-användare. Observera att du inte kan ändra dina egna användarattribut med hjälp av det här formuläret, och måste göra ändringar till din egen användare enskilt.',
    'bulk_update_help'	=> 'Den här blanketten låter dig uppdatera flera användare samtidigt. Fyll bara i de fält du behöver ändra. Alla fält som lämnas tomma kommer att förbli oförändrade.',
    'current_assets'    => 'Tillgångar som för närvarande kontrolleras ut till den här användaren',
    'clone'             => 'Klonanvändare',
    'contact_user'      => 'Kontaktnamn',
    'edit'              => 'Redigera användare',
    'filetype_info'     => 'Tillåtna filtyper är png, gif, jpg, jpeg, doc, docx, pdf, txt, zip och rar.',
    'history_user'      => 'Historia för: namn',
	'info'				=> 'Info',
    'restore_user'		=> 'Klicka här för att återställa dem.',
    'last_login'        => 'Senaste inloggning',
    'ldap_config_text'  => 'LDAP-konfigurationsinställningar finns Admin> Inställningar. Den (valfria) valda platsen kommer att ställas in för alla importerade användare.',
    'print_assigned'    => 'Skriv ut alla tilldelade',
    'software_user'     => 'Programvara Kontrollerad till: namn',
    'send_email_help'   => 'Du måste ange en e-postadress till användaren för att kunna skicka inloggningsuppgifterna. Utskick av inloggningsuppgifter kan endast göras när användaren skapas. Lösenorden lagras i en one-way hash och kan inte hämtas när de väl sparats.',
    'view_user'         => 'Visa användare: namn',
    'usercsv'           => 'CSV-fil',
    'two_factor_admin_optin_help' => 'Dina nuvarande administratörsinställningar tillåter selektiv tillämpning av tvåfaktorsautentisering.  ',
    'two_factor_enrolled' => '2FA-enhet inskriven',
    'two_factor_active'   => '2FA Aktiv',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/sv-SE/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Den här användaren kan logga in',
    'activated_disabled_help_text' => 'Du kan inte redigera aktiveringsstatus för ditt eget konto.',
    'assets_user'       => 'Tillgångar tilldelade: namn',
    'bulk_update_warn'	=> 'Du håller på att redigera egenskaperna hos: user_count-användare. Observera att du inte kan ändra dina egna användarattribut med hjälp av det här formuläret, och måste göra ändringar till din egen användare enskilt.',
    'bulk_update_help'	=> 'Den här blanketten låter dig uppdatera flera användare samtidigt. Fyll bara i de fält du behöver ändra. Alla fält som lämnas tomma kommer att förbli oförändrade.',
    'current_assets'    => 'Tillgångar som för närvarande kontrolleras ut till den här användaren',
    'clone'             => 'Klonanvändare',
    'contact_user'      => 'Kontaktnamn',
    'edit'              => 'Redigera användare',
    'filetype_info'     => 'Tillåtna filtyper är png, gif, jpg, jpeg, doc, docx, pdf, txt, zip och rar.',
    'history_user'      => 'Historia för: namn',
    'info'				=> 'Info',
    'restore_user'		=> 'Klicka här för att återställa dem.',
    'last_login'        => 'Senaste inloggning',
    'ldap_config_text'  => 'LDAP-konfigurationsinställningar finns Admin> Inställningar. Den (valfria) valda platsen kommer att ställas in för alla importerade användare.',
    'print_assigned'    => 'Skriv ut alla tilldelade',
    'software_user'     => 'Programvara Kontrollerad till: namn',
    'send_email_help'   => 'Du måste ange en e-postadress till användaren för att kunna skicka inloggningsuppgifterna. Utskick av inloggningsuppgifter kan endast göras när användaren skapas. Lösenorden lagras i en one-way hash och kan inte hämtas när de väl sparats.',
    'view_user'         => 'Visa användare: namn',
    'usercsv'           => 'CSV-fil',
    'two_factor_admin_optin_help' => 'Dina nuvarande administratörsinställningar tillåter selektiv tillämpning av tvåfaktorsautentisering.  ',
    'two_factor_enrolled' => '2FA-enhet inskriven',
    'two_factor_active'   => '2FA Aktiv',
    'user_deactivated'  => 'Användaren är inaktiverad',
    'activation_status_warning' => 'Ändra inte aktiveringsstatus',
    'group_memberships_helpblock' => 'Endast superadministratörer kan redigera gruppmedlemskap.',
    'superadmin_permission_warning' => 'Endast superadministratörer kan ge en användare superadmin åtkomst.',
    'admin_permission_warning' => 'Endast användare med administratörsrättigheter eller högre kan ge administratörsbehörighet.',
    'remove_group_memberships' => 'Ta bort gruppmedlemskap',
    'warning_deletion' => 'VARNING:',
    'warning_deletion_information' => 'Du håller på att ta bort :count användare som anges nedan. Super admin namn markeras med rött.',
    'update_user_asssets_status' => 'Uppdatera alla tillgångar för dessa användare till denna status',
    'checkin_user_properties' => 'Kolla in alla egenskaper som är associerade med dessa användare',
];
